@@ -8,9 +8,13 @@ impl ResultFn for () {
     fn result(self) {}
 }
 
-struct Id<T> (T);
+pub struct Id<T> (T);
 
 impl<T> ResultFn for Id<T> {
     type Result = T;
     fn result(self) -> T { self.0 }
 }
+
+impl<T> Id<T> {
+    pub fn new(v: T) -> Self { Self(v) }
+}
\ No newline at end of file
